@@ -8,6 +8,8 @@ class DevPreToolbox(Toplevel):
         """
         在测试窗口时可以使用工具箱来调整窗口。
 
+        :param master: 组件的父组件
+        :param title: 工具箱的标题
         """
         super(DevPreToolbox, self).__init__(master=master)
         from tkdev import window_move, window_border
